searchData={"content_type":"text/markdown","items":[{"doc":"Add telemetry events to your supervisors to track child startup times.","ref":"TelemetryChildInit.html","title":"TelemetryChildInit","type":"module"},{"doc":"The package can be installed by adding `telemetry_child_init` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:telemetry_child_init, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"TelemetryChildInit.html#module-installation","title":"Installation - TelemetryChildInit","type":"module"},{"doc":"","ref":"TelemetryChildInit.html#module-usage","title":"Usage - TelemetryChildInit","type":"module"},{"doc":"```elixir\ndefmodule DummySupervisor do\n  use Supervisor\n\n  def start_link(init_arg) do\n    Supervisor.start_link(__MODULE__, init_arg, name: __MODULE__)\n  end\n\n  @impl true\n  def init(_init_arg) do\n    children =\n      [{DummyChild, []}]\n      |> TelemetryChildInit.instrument(__MODULE__)\n\n    Supervisor.init(children, strategy: :one_for_one)\n  end\nend\n```","ref":"TelemetryChildInit.html#module-instrument-your-supervisor","title":"Instrument your supervisor: - TelemetryChildInit","type":"module"},{"doc":"```elixir\n:telemetry_test.attach_event_handlers(self(), [\n  [:supervisor, :startup, :start],\n  [:supervisor, :startup, :stop],\n  [:supervisor, :child, :init, :start],\n  [:supervisor, :child, :init, :stop],\n  [:supervisor, :child, :init, :exception]\n])\n```","ref":"TelemetryChildInit.html#module-collect-telemetry-events","title":"Collect telemetry events - TelemetryChildInit","type":"module"},{"doc":"The following Events are emitted\n\n* `[:supervisor, :startup, :start]` — before the first child is started\n* `[:supervisor, :startup, :stop]` — after all children have been started\n* `[:supervisor, :child, :init, :start]` — at the point the child's init call is called\n* `[:supervisor, :child, :init, :stop]` — after the child's init call has completed\n* `[:supervisor, :child, :init, :exception]` — when a child's init callback has had an exception\n\nThe following chart shows which metadata you can expect for each event:\n\n| event                                      | measures                          | metadata                                                                                                           |\n| ------------------------------------------ | --------------------------------- | ------------------------------------------------------------------------------------------------------------------ |\n| `[:supervisor, :startup, :start]`          | `:system_time`, `:monotonic_time` | `:supervisor_module`, `:ref`                                                                                       |\n| `[:supervisor, :startup, :stop]`           | `:duration`, `:monotonic_time`    | `:supervisor_module`, `:ref`                                                                                       |\n| `[:supervisor, :child, :init, :start]`     | `:system_time`, `:monotonic_time` | `:telemetry_span_context`, `:supervisor_module`, `:ref`, `:module`                                                 |\n| `[:supervisor, :child, :init, :stop]`      | `:duration`, `:monotonic_time`    | `:telemetry_span_context`, `:supervisor_module`, `:ref`, `:function`                                               |\n| `[:supervisor, :child, :init, :exception]` | `:duration`, `:monotonic_time`    | `:telemetry_span_context`, `:supervisor_module`, `:ref`, `:module`, `:function`, `:kind`, `:reason`, `:stacktrace` |","ref":"TelemetryChildInit.html#module-telemetry-events","title":"Telemetry Events - TelemetryChildInit","type":"module"},{"doc":"* `:supervisor_module` — The module name for the supervisor itself\n* `:telemetry_span_context` — A ref that corresponds to one instance of the supervisor, can be used to correlate start and stop events\n\nFor `:exception` events the metadata also includes details about what caused the failure. The\n`:kind` value is determined by how an error occurred. Here are the possible kinds:\n\n* `:error` — from an `{:error, error}` return value. Some Erlang functions may also throw an `:error` tuple, which will be reported as `:error`\n* `:exit` — from a caught process exit\n* `:throw` — from a caught value, this doesn't necessarily mean that an error occurred and the error value is unpredictable","ref":"TelemetryChildInit.html#module-metadata","title":"Metadata - TelemetryChildInit","type":"module"},{"doc":"","ref":"TelemetryChildInit.html#init/3","title":"TelemetryChildInit.init/3","type":"function"},{"doc":"","ref":"TelemetryChildInit.html#instrument/2","title":"TelemetryChildInit.instrument/2","type":"function"},{"doc":"","ref":"TelemetryChildInit.Start.html","title":"TelemetryChildInit.Start","type":"module"},{"doc":"","ref":"TelemetryChildInit.Start.html#init/3","title":"TelemetryChildInit.Start.init/3","type":"function"},{"doc":"","ref":"TelemetryChildInit.Stop.html","title":"TelemetryChildInit.Stop","type":"module"},{"doc":"","ref":"TelemetryChildInit.Stop.html#init/3","title":"TelemetryChildInit.Stop.init/3","type":"function"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}